@@ -10,25 +10,34 @@ def get_html_compressor_jar_filename():
     """Return the full path to the HTML Compressor Java archive."""
     return resource_filename(__name__, "htmlcompressor.jar")
 
-def main():
+def get_datauri_jar_filename():
+    """Return the full path to the HTML Compressor Java archive."""
+    return resource_filename(__name__, "datauri.jar")
+
+def get_cssembed_jar_filename():
+    """Return the full path to the HTML Compressor Java archive."""
+    return resource_filename(__name__, "cssembed.jar")
+
+def execute_jar_command(jar_file):
     name = sys.argv[0]
-    
+    os.execlp("java", 
+        name, 
+        "-jar", 
+        jar_file, 
+        *sys.argv[2:]
+    )
+
+def main():    
     if len(sys.argv) > 2:
         subcommand = sys.argv[1]
         if subcommand == 'htmlcompressor':
-            os.execlp("java", 
-                name, 
-                "-jar", 
-                get_html_compressor_jar_filename(), 
-                *sys.argv[2:]
-            )
+            execute_jar_command(get_html_compressor_jar_filename())
         elif subcommand == "yuicompressor":
-            os.execlp("java", 
-                name, 
-                "-jar", 
-                get_yui_compressor_jar_filename(), 
-                *sys.argv[2:]
-            )
+            execute_jar_command(get_yui_compressor_jar_filename())
+        elif subcommand == "cssembed":
+            execute_jar_command(get_cssembed_jar_filename())
+        elif subcommand == "datauri":
+            execute_jar_command(get_datauri_jar_filename())
         else:
             show_usage()
     else:
@@ -36,7 +45,7 @@ def main():
 
 def show_usage():
     sys.stdout.write('''
-    Usage: squeeze [htmlcompressor|yuicompressor] [options]
+    Usage: squeeze [htmlcompressor|yuicompressor|cssembed|datauri] [options]
     ''')
     sys.exit(1)
 
